@@ -6,6 +6,7 @@ import six
 from six.moves import cStringIO
 import codecs
 import os.path
+import re
 import sqlalchemy
 import sqlparse
 import prettytable
@@ -65,11 +66,25 @@ class CsvResultDescriptor(object):
         return 'CSV results at %s' % os.path.join(os.path.abspath('.'), self.file_path)
     def _repr_html_(self):
         return '<a href="%s">CSV results</a>' % os.path.join('.', 'files', self.file_path)
-    
+
+
+def _nonbreaking_spaces(match_obj):
+    """
+    Make spaces visible in HTML by replacing all `` `` with ``&nbsp;``
+
+    Call with a ``re`` match object.  Retain group 1, replace group 2
+    with nonbreaking speaces.
+    """
+    spaces = '&nbsp;' * len(match_obj.group(2))
+    return '%s%s' % (match_obj.group(1), spaces)
+
+_cell_with_spaces_pattern = re.compile(r'(<td>)( {2,})')
+
+
 class ResultSet(list, ColumnGuesserMixin):
     """
     Results of a SQL query.
-    
+
     Can access rows listwise, or by string value of leftmost column.
     """
     def __init__(self, sqlaproxy, sql, config):
@@ -94,8 +109,10 @@ class ResultSet(list, ColumnGuesserMixin):
             list.__init__(self, [])
             self.pretty = None
     def _repr_html_(self):
+        _cell_with_spaces_pattern = re.compile(r'(<td>)( {2,})')
         if self.pretty:
             result = self.pretty.get_html_string()
+            result = _cell_with_spaces_pattern.sub(_nonbreaking_spaces, result)
             if self.config.displaylimit and len(self) > self.config.displaylimit:
                 result = '%s\n<span style="font-style:italic;text-align:center;">%d rows, truncated to displaylimit of %d</span>' % (
                     result, len(self), self.config.displaylimit)
@@ -125,23 +142,23 @@ class ResultSet(list, ColumnGuesserMixin):
         return frame
     def pie(self, key_word_sep=" ", title=None, **kwargs):
         """Generates a pylab pie chart from the result set.
-       
+
         ``matplotlib`` must be installed, and in an
         IPython Notebook, inlining must be on::
-        
+
             %%matplotlib inline
-            
-        Values (pie slice sizes) are taken from the 
+
+        Values (pie slice sizes) are taken from the
         rightmost column (numerical values required).
         All other columns are used to label the pie slices.
-        
+
         Parameters
         ----------
         key_word_sep: string used to separate column values
                       from each other in pie labels
         title: Plot title, defaults to name of value column
 
-        Any additional keyword arguments will be passsed 
+        Any additional keyword arguments will be passsed
         through to ``matplotlib.pylab.pie``.
         """
         self.guess_pie_columns(xlabel_sep=key_word_sep)
@@ -149,23 +166,23 @@ class ResultSet(list, ColumnGuesserMixin):
         pie = plt.pie(self.ys[0], labels=self.xlabels, **kwargs)
         plt.title(title or self.ys[0].name)
         return pie
-  
+
     def plot(self, title=None, **kwargs):
         """Generates a pylab plot from the result set.
-       
+
         ``matplotlib`` must be installed, and in an
         IPython Notebook, inlining must be on::
-        
+
             %%matplotlib inline
-           
+
         The first and last columns are taken as the X and Y
         values.  Any columns between are ignored.
-        
+
         Parameters
         ----------
         title: Plot title, defaults to names of Y value columns
 
-        Any additional keyword arguments will be passsed 
+        Any additional keyword arguments will be passsed
         through to ``matplotlib.pylab.plot``.
         """
         import matplotlib.pylab as plt
@@ -179,25 +196,25 @@ class ResultSet(list, ColumnGuesserMixin):
         plt.title(title or ylabel)
         plt.ylabel(ylabel)
         return plot
-    
+
     def bar(self, key_word_sep = " ", title=None, **kwargs):
         """Generates a pylab bar plot from the result set.
-       
+
         ``matplotlib`` must be installed, and in an
         IPython Notebook, inlining must be on::
-        
+
             %%matplotlib inline
-           
+
         The last quantitative column is taken as the Y values;
-        all other columns are combined to label the X axis. 
-        
+        all other columns are combined to label the X axis.
+
         Parameters
         ----------
         title: Plot title, defaults to names of Y value columns
         key_word_sep: string used to separate column values
                       from each other in labels
-                      
-        Any additional keyword arguments will be passsed 
+
+        Any additional keyword arguments will be passsed
         through to ``matplotlib.pylab.bar``.
         """
         import matplotlib.pylab as plt
@@ -208,8 +225,8 @@ class ResultSet(list, ColumnGuesserMixin):
                        rotation=45)
         plt.xlabel(self.xlabel)
         plt.ylabel(self.ys[0].name)
-        return plot        
-    
+        return plot
+
     def csv(self, filename=None, **format_params):
         """Generate results in comma-separated form.  Write to ``filename`` if given.
            Any other parameterw will be passed on to csv.writer."""
@@ -228,8 +245,8 @@ class ResultSet(list, ColumnGuesserMixin):
             return CsvResultDescriptor(filename)
         else:
             return outfile.getvalue()
-        
-    
+
+
 def interpret_rowcount(rowcount):
     if rowcount < 0:
         result = 'Done.'
@@ -241,8 +258,11 @@ def interpret_rowcount(rowcount):
 def run(conn, sql, config, user_namespace):
     if sql.strip():
         for statement in sqlparse.split(sql):
+            if sql.strip().split()[0].lower() == 'begin':
+                raise Exception("ipython_sql does not support transactions")
             txt = sqlalchemy.sql.text(statement)
             result = conn.session.execute(txt, user_namespace)
+            conn.session.execute('commit')
             if result and config.feedback:
                 print(interpret_rowcount(result.rowcount))
         resultset = ResultSet(result, statement, config)
@@ -253,4 +273,3 @@ def run(conn, sql, config, user_namespace):
         #returning only last result, intentionally
     else:
         return 'Connected: %s' % conn.name
-     
\ No newline at end of file
